@@ -3,7 +3,7 @@ BEGIN {
   $App::QuoteCC::AUTHORITY = 'cpan:AVAR';
 }
 BEGIN {
-  $App::QuoteCC::VERSION = '0.06';
+  $App::QuoteCC::VERSION = '0.07';
 }
 
 use 5.010;
@@ -14,7 +14,12 @@ use namespace::clean -except => 'meta';
 
 with qw/ MooseX::Getopt::Dashes /;
 
-has help => (
+# MooseX::Getopt 81b19ed83c by Karen Etheridge changed the help
+# attribute to help_flag.
+{
+my @go_attrs = MooseX::Getopt::GLD->meta->get_attribute_list;
+my $help_attr = 'help_flag' ~~ @go_attrs ? 'help_flag' : 'help';
+has $help_attr => (
     traits        => [ qw/ Getopt / ],
     cmd_aliases   => 'h',
     cmd_flag      => 'help',
@@ -23,6 +28,7 @@ has help => (
     default       => 0,
     documentation => 'This help message',
 );
+}
 
 has input => (
     traits        => [ qw/ Getopt / ],
